@@ -1,12 +1,11 @@
 """Standalone module that validates Sonata circuit. See ``validate`` function."""
 import itertools as it
+from pathlib import Path
 
 import numpy as np
 import pandas as pd
 import click
-from pathlib2 import Path
 import h5py
-import six
 
 from bluepysnap import BluepySnapError
 from bluepysnap.config import Config
@@ -231,11 +230,14 @@ def _nodes_group_to_dataframe(group, types_file, population):
     df = df[df['group_id'] == int(str(_get_group_name(group)))]
     for k, v in group.items():
         if isinstance(v, h5py.Dataset):
-            df[k] = v[:]
+            if v.dtype == h5py.string_dtype():
+                df[k] = v.asstr()[:]
+            else:
+                df[k] = v[:]
     if '@library' in group:
         for k, v in group['@library'].items():
             if isinstance(v, h5py.Dataset):
-                df[k] = v[:][df[k].to_numpy(dtype=int)]
+                df[k] = v.asstr()[:][df[k].to_numpy(dtype=int)]
     if types_file is None:
         return df
     types = pd.read_csv(types_file, sep=r'\s+')
@@ -450,7 +452,7 @@ def _check_edges_node_ids(nodes_ds, nodes):
     """
     if 'node_population' not in nodes_ds.attrs:
         return [fatal('Missing "node_population" attribute for "{}"'.format(nodes_ds.name))]
-    node_population_name = six.ensure_str(nodes_ds.attrs['node_population'])
+    node_population_name = nodes_ds.attrs['node_population']
     nodes_dict = _find_nodes_population(node_population_name, nodes)
     if not nodes_dict:
         return [fatal('No node population for "{}"'.format(nodes_ds.name))]
